# Talksheet

Talksheet is an AI-powered CLI tool for exploring data.

It can read data from local CSV files

![local_csv_example](assets/pic_loca_csv.png)

And from remote CSV files

![remote_csv_example](assets/pic_remote_csv.png)


## Installation

Talksheet is available on PyPI. You can install it with pip:

```bash
pip install talksheet
```

## Usage

Talksheet is a CLI tool. You can run it with the `talksheet` command.

```bash
export OPENAI_API_KEY=<your_openai_api_key>

talksheet
```

## Roadmap

- Better UI/UX
- Handle more data formats
- Export results